

library(shiny)
#library(ygdashboard)
devtools::install_github("ygdashboard")
library(leaflet)
library(magrittr)
library(DT)
library(maps)
library(devtools)
devtools::install_github("ygdashboard", username = "gyang274")

#- server.R: 

#- create_dynamicChatMessage()
allChatMessage <- list() # keep hist of all chat message

#- create_leafletMap()
#mapStates = map("state", fill = TRUE, plot = FALSE)

#------------------------------------------------------------------------------#

library("shinyWidgets")
if (!require("formatR")) install.packages("formatR")



# Ids widgets
ids <- paste0("Id", sprintf("%03d", 1:100))
idss <- ids

ID <- function(ids) {
  if (length(ids) == 0) stop("Not enougth IDs")
  res <- ids[1]
  ids <<- ids[-1]
  return(res)
}


# Widget wrapper ----

widget_wrapper <- function(fun, args){
  
  # raw <- paste(
  #   capture.output(
  #     match.call(fun, do.call("call", c(deparse(substitute(fun)), args)))
  #   ),
  #   collapse = " "
  # )
  raw <- paste0(
    deparse(substitute(fun)),
    gsub(
      pattern = "^list", replacement = "",
      x = paste(deparse(substitute(args)), collapse = "")
    )
  )
  raw <- gsub(pattern = "ID\\(ids\\)", replacement = paste0("\"", args$inputId, "\""), x = raw)
  
  
  formatted <- formatR::tidy_source(
    text = raw,
    output = FALSE,
    width.cutoff = 30,
    indent = 2,
    brace.newline = FALSE
  )$text.tidy
  
  tagList(
    do.call(fun, args),
    tags$b("Value :"),
    verbatimTextOutput(outputId = paste0("res", args$inputId)),
    tags$b(tags$a(icon("code"), "Show code", `data-toggle`="collapse", href=paste0("#showcode", args$inputId))),
    tags$div(
      class="collapse", id=paste0("showcode", args$inputId),
      rCodeContainer(
        id=paste0("code", args$inputId),
        formatted
      )
    )
  )
}


box_wrapper <- function(title, ..., footer = NULL) {
  box(
    title = title, status = "danger", width = NULL, footer = footer,
    ...
  )
}


pb_code <- function(id, ui, server) {
  tagList(
    tags$b(tags$a(icon("code"), "Show code", `data-toggle`="collapse", href=paste0("#showcode", id))),
    tags$div(
      class="collapse", id=paste0("showcode", id),
      rCodeContainer(
        id=paste0("code", id),
        paste(
          "# ui",
          ui,
          "# server",
          server,
          sep = "\n"
        )
      )
    )
  )
}


# Highlight functions ----

injectHighlightHandler <- function() {
  
  code <- "
  Shiny.addCustomMessageHandler('highlight-code', function(message) {
  var id = message['id'];
  setTimeout(function() {
  var el = document.getElementById(id);
  hljs.highlightBlock(el);
  }, 100);
  });
  "
  
  tags$script(code)
}


includeHighlightJs <- function() {
  resources <- system.file("www/shared/highlight", package = "shiny")
  list(
    includeScript(file.path(resources, "highlight.pack.js")),
    includeCSS(file.path(resources, "rstudio.css")),
    injectHighlightHandler()
  )
}

highlightCode <- function(session, id) {
  session$sendCustomMessage("highlight-code", list(id = id))
}

rCodeContainer <- function(...) {
  code <- HTML(as.character(tags$code(class = "language-r", ...)))
  div(pre(code))
}

renderCode <- function(expr, env = parent.frame(), quoted = FALSE) {
  func <- NULL
  installExprFunction(expr, "func", env, quoted)
  markRenderFunction(textOutput, function() {
    paste(func(), collapse = "\n")
  })
}


library(lme4)
library(dplyr)
library(nlme)
library(ggplot2)
library(mgcv)
library(Matrix)
library(gridExtra)
library(grid)
library(lsmeans)
library(car)

library(knitr)
library("shiny")
library(shinydashboard)
library("foreign")

library(ggplot2)
library("gridExtra")
library("grid")
library(latex2exp)

#' Function that compute the scaled residual of linear mixed model
#' @title Computation of the scaled residual of lme model
#' @author Aurelien Nicosia
#' @param object an object inheriting from class lme, representing a fitted linear mixed-effects model.
#' @return ScaleRes vector scaled residual


ScaledResid <-function(object){
  
  V = extract.lme.cov(object, object$data);
  
  C <- chol(as.matrix(V));
  rm <- residuals(object, level = 0);
  ScaledRes <- solve(t(C)) %*% rm;
  return(ScaledRes);
  
}





gg_qq <- function(object, distribution = "norm", ..., line.estimate = NULL, conf = 0.95,
                  labels = names(x)){
  
  resid = ScaledResid(object)
  
  # fitted vs predicted
  df = data.frame(predicted.mean=object$fitted,residual=resid)
  p1 = ggplot(df, aes(x=predicted.mean.fixed, y=residual)) +
    geom_point( colour="blue")  + geom_abline(intercept = 0, slope = 0)+
    labs( x="Predicted Mean", y=" Residual")
  
  
  # histogram
  residual=data.frame(resid=resid)
  gg <- ggplot(residual, aes(x=resid))
  range.residual=range(residual$resid)
  gg <- gg + geom_histogram( binwidth=(range.residual[2]-range.residual[1])/10 ,colour="black",
                             aes(y=..density.., fill=..count..))
  #gg <- gg + scale_fill_gradient("Count")
  p2 <- gg + stat_function(fun=dnorm,
                           color="red",
                           args=list(mean=mean(residual$resid),
                                     sd=sd(residual$resid)))
  
  
  
  
  
  #QQ-plot
  x = resid
  q.function <- eval(parse(text = paste0("q", distribution)))
  d.function <- eval(parse(text = paste0("d", distribution)))
  x <- na.omit(x)
  ord <- order(x)
  n <- length(x)
  P <- ppoints(length(x))
  df <- data.frame(ord.x = x[ord], z = q.function(P, ...))
  
  if(is.null(line.estimate)){
    Q.x <- quantile(df$ord.x, c(0.25, 0.75))
    Q.z <- q.function(c(0.25, 0.75), ...)
    b <- diff(Q.x)/diff(Q.z)
    coef <- c(Q.x[1] - b * Q.z[1], b)
  } else {
    coef <- coef(line.estimate(ord.x ~ z))
  }
  
  zz <- qnorm(1 - (1 - conf)/2)
  SE <- (coef[2]/d.function(df$z)) * sqrt(P * (1 - P)/n)
  fit.value <- coef[1] + coef[2] * df$z
  df$upper <- fit.value + zz * SE
  df$lower <- fit.value - zz * SE
  
  if(!is.null(labels)){
    df$label <- ifelse(df$ord.x > df$upper | df$ord.x < df$lower, labels[ord],"")
  }
  
  p3 <- ggplot(df, aes(x=z, y=ord.x)) +
    geom_point(colour="Blue") +
    geom_abline(intercept = coef[1], slope = coef[2]) +
    geom_ribbon(aes(ymin = lower, ymax = upper), alpha=0.2)  +
    labs( x="Theoretical Quantiles", y=" Residuals")
  if(!is.null(labels)) p <- p + geom_text( aes(label = label))
  
  
  # boxplot of residuals
  residual$boxplot=as.factor(rep(1,length(residual$resid)))
  p4 = ggplot(residual, aes( x=boxplot,y=resid)) + geom_boxplot(colour= "blue")
  
  
  
  multiplot(p1, p2, p3, p4,cols=2)
  
  
  #grid.arrange(p1,p2,p3,p4, ncol=2, nrow=2, top = "Diagnostic plots for scaled residuals")
  
  
  
  
}
hist.resid <- function(resid){
  residual=data.frame(resid=resid)
  gg <- ggplot(residual, aes(x=resid))
  gg <- gg + geom_histogram( bins= 12,colour="black",
                             aes(y=..density.., fill=..count..))
  gg <- gg + scale_fill_gradient("Count")
  gg <- gg + stat_function(fun=dnorm,
                           color="red",
                           args=list(mean=mean(residual$resid),
                                     sd=sd(residual$resid)))
  
  gg
}


multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}


# exemple application de la nouvelle fonction


lme.SCS <- function(fixed, data = sys.frame(sys.parent()), random, correlation = NULL,
                    weights = NULL, subset , method = c("REML", "ML"), na.action = na.fail,
                    control = list(), contrasts = NULL, keep.data = TRUE, type = 'marginal',
                    Lsmeans = NULL
                    
                    
){
  
  
  model <- lme(fixed , data , random , correlation ,
               weights , subset ,
               method , na.action, control ,
               contrasts   , keep.data )
  
  
  return(model)
  
}

plot.lme.SCS<- function(model, ...){
  diag.plot = gg_qq(model)
}


print.lme.SCS <- function(model, type = 'marginal', ...){
  x <- summary(model)
  fit=data.frame(Fit=c(-2*model$logLik, summary(model)$AIC,  summary(model)$BIC))
  rownames(fit) = c('-2 Res Log Likelihood', 'AIC (smaller is better)', 'BIC (smaller is better)')
  colnames(fit) = 'Fit Statistics'
  cat('\n')
  cat('************************************************')
  cat('\n')
  dd <- x$dims
  verbose = FALSE
  verbose <- verbose || attr(x, "verbose")
  if (inherits(x, "nlme")) {
    cat("Nonlinear mixed-effects model fit by ")
    cat(ifelse(x$method == "REML", "REML\n", "maximum likelihood\n"))
    cat("  Model:", deparse(x$call$model), "\n")
  }
  else {
    cat("Linear mixed-effects model fit by ")
    cat(ifelse(x$method == "REML", "REML\n", "maximum likelihood\n"))
  }
  cat('\n')
  
  cat("\nNumber of Observations:", x$dims[["N"]])
  cat("\nNumber of Groups: ")
  Ngrps <- dd$ngrps[1:dd$Q]
  if ((lNgrps <- length(Ngrps)) == 1) {
    cat(Ngrps, "\n")
  }
  else {
    sNgrps <- 1:lNgrps
    aux <- rep(names(Ngrps), sNgrps)
    aux <- split(aux, array(rep(sNgrps, lNgrps), c(lNgrps,
                                                   lNgrps))[!lower.tri(diag(lNgrps))])
    names(Ngrps) <- unlist(lapply(aux, paste, collapse = " %in% "))
    cat("\n")
    print(rev(Ngrps))
  }
  
  cat('\n')
  print(fit)
  if (verbose) {
    cat("Convergence at iteration:", x$numIter, "\n")
  }
  cat("\n")
  cat('************************************************')
  cat("\n")
  
  print(summary(x$modelStruct), sigma = x$sigma, reEstimates = x$coef$random,
        verbose = verbose)
  cat('\n')
  cat('************************************************')
  
  cat("\nAnalyse of Variance")
  cat('\n')
  
  aov.table = anova.lme(model, type = type)
  print(aov.table)
  cat('\n')
  
  cat('************************************************')
  cat('\n')
  cat("\nScaled Residuals:\n")
  sum.res=summary(ScaledResid(model))
  colnames(sum.res) <- NULL
  
  cat(sum.res)
  cat("\n")
  invisible(x)
  cat('************************************************')
  
}
print.consensus <- function(x, ...) {
  cat("\nMaximum log-likelihood :", x$MaxLL, "\n")
  cat("\nKappa Parameters:\n")
  print.default(x$parameters, print.gap = 2, quote = FALSE, 
                right = TRUE, ...)
  cat("\n")
  # cat('\nBeta Parameters:\n') print.default(x$parambeta,
  # print.gap = 2, quote = FALSE, right=TRUE, ...) cat('\n')
  invisible(x)
}

