#
# This is the user-interface definition of a Shiny web application. You can
# run the application by clicking 'Run App' above.
#
# Find out more about building applications with Shiny here:
# 
#    http://shiny.rstudio.com/
#

library(shiny)
library(shinydashboard)
library(shinyWidgets)
library(vembedr)
library(shinyBS)
library(colourpicker)
library(plotly)

# Define UI for application that draws a histogram

dashboardPage(
  skin = "purple", title = "R à Québec",
dashboardHeader(
    title = HTML(paste0(
      '<span class = "logo-lg"><b>Aurélien Nicosia</b> R à Québec</span>',
      '<span class = "logo-mini"><b>R Québec</b></span>'
    )),
    
    titleWidth = 300
    #user = dashboardUser("user")
    #user = ygdashboard::userOutput("user")
    
    
  ),
dashboardSidebar(
    width = 300,
    
    ygdashboard::sidebarUserPanelOutput(outputId = "dynamicSidebarUserPanel"),
    sidebarMenu(
      menuItem("Introduction", tabName = "intro"),
     ygdashboard::menuSegment("LES SHINY APPS"),
     menuItem("Inputs", tabName = "input2", icon = icon("dashboard")),
     menuItem("Outputs", tabName = "output",badgeLabel = "new", badgeColor = "green", icon = icon("file-code-o")),
     menuItem(text = "Other stuffs", tabName = "tabOtherStuff", icon = icon("plus-circle")),
     menuItem("Quoi d'autres", tabName = 'Autres',
              menuSubItem('Youtube Video', tabName = 'video'),
              menuSubItem("Rapport automatique", tabName = 'rapport'),
              menuSubItem("Google Maps", tabName = 'ggmap')),
     ygdashboard::menuSegment("Application"),
     menuItem("Google Ngram", tabName = "Ngram"),
     menuItem("Echantillonage", collapsible= TRUE,
              
              ygdashboard::menuSegment("Plan aleatoire simple"),
              
                       menuSubItem("Calcul Taille", tabName = "taille"),
                       menuSubItem("Calcul Marge", tabName = "marge"),
     ygdashboard::menuSegment("Plan Stratifie"),
     
     
                       menuSubItem("Calcul Taille", tabName = "taillestrat"),
                       menuSubItem("Calcul Marge", tabName = "margestart")
              
              ),
     menuItem("Mixed model", tabName = "mixed"),
     menuItem("Text mining", tabName = "text"),
     menuItem("Exemples", tabName = "krsl", icon = icon("spinner"))
     

             
     
    )
     # ,
     # HTML("
     #    <link href='media.css' rel='stylesheet' type='text/css'>
     # 
     #      <nav class='social'>
     #      <ul>
     #      <li><a href='mailto:info@rayharvey.ca?Subject=Information%Cruncher'>Courriel <i class='fa fa-envelope'></i></a></li>
     #      <li><a href='tel:14188497777'>(418) 849-7777 <i class='fa fa-phone'></i></a></li>
     # 
     #      </ul>
     # 
     #      ")
     # 
  ),
  dashboardBody(
    bsModal("modalExample", "Data Table", "tabBut", size = "large",
            DT::dataTableOutput('inputdata')),
    tabItems(
      tabItem("intro",
              
              htmlOutput('pdfviewer')
      ),
    tabItem(
      tabName = "tabOtherStuff",
      
      tags$h1("Other stuffs", style = "font-weight: bold; color: #d9534f;"),
      
      fluidRow(
        
        box(
          title = "Dropdown Button", status = "danger", width = 8,
          dropdownButton(
            tags$h3("List of Input"),
            selectInput(inputId = 'xcol', label = 'X Variable', choices = names(iris)),
            selectInput(inputId = 'ycol', label = 'Y Variable', choices = names(iris), selected = names(iris)[[2]]),
            sliderInput(inputId = 'clusters', label = 'Cluster count', value = 5, min = 1, max = 9),
            circle = TRUE, status = "danger", icon = icon("gear"), width = "300px",
            tooltip = tooltipOptions(title = "Click to see inputs !")
          ),
        plotOutput(outputId = 'plotkmeans2')
        ),
        
        box(
          title = "Sweet Alert", status = "danger", width = 4,
          tags$span(
            "via ",
            tags$a(href = "http://t4t5.github.io/sweetalert/", "sweetalert"),
            style="color: #d9534f;"
          ), br(), br(),
          fluidRow(
            column(
              width = 6,
              actionButton(inputId = "success", label = "Success !", width = "100%", class = "btn-success", style = "color: #FFF"),
              receiveSweetAlert(messageId = "successmessage"),
              br(), br(),
              actionButton(inputId = "tags", label = "With HTML tags", width = "100%"),
              receiveSweetAlert(messageId = "tagsmessage"),
              br(), br(),
              actionButton(inputId = "info", label = "Info", width = "100%", class = "btn-info", style = "color: #FFF"),
              receiveSweetAlert(messageId = "infomessage")
            ),
            column(
              width = 6,
              actionButton(inputId = "error", label = "Error", width = "100%", class = "btn-danger", style = "color: #FFF"),
              receiveSweetAlert(messageId = "errormessage"),
              br(), br(),
              actionButton(inputId = "warning", label = "Warning", width = "100%", class = "btn-warning", style = "color: #FFF"),
              receiveSweetAlert(messageId = "warningmessage")
            )
          )
        )
        
      )
    ) ,
    tabItem(tabName = "input2",
            h2('Les differents inputs disponibles:'),
            fluidRow(
              box(width = 4, title = 'Buttons',
                  awesomeCheckboxGroup(inputId = "Id025", 
                                       label = "Checkboxes", choices = c("A", 
                                                                         "B", "C"), selected = "A", 
                                       inline = TRUE, status = "danger")),
              box(width = 4, title = 'checkboxGroupInput', 
                  awesomeRadio(inputId = "Id026", 
                               label = "Radio buttons", choices = c("A", 
                                                                    "B", "C"), selected = "A", 
                               inline = TRUE, status = "success")
              ),
              box(width = 4, title = 'Date input', 
                  shiny::dateInput("action4", label = " "),
                  br(),
                  p(code("dateInput()")),
                  br(),
                  shiny::dateRangeInput("action5", label = " "),
                  br(),
                  p(code("dateRangeInput()")))
              
              
            ),
            fluidRow(
              box(width = 4, title = 'File input', 
                  shiny::fileInput("action6", label = " "),
                  br(),
                  p(code("fileInput()"))
              ),
              box(width = 4, title = 'Numeric input', 
                  numericInput("action7", label = " ", value = 3),
                  br(),
                  p(code("numericInput()"))
              ),
              box(width = 4, title = 'Numeric input', 
                pickerInput(
                  inputId = "id", 
                  label = "Select/deselect all options", 
                  choices = LETTERS, options = list(`actions-box` = TRUE), 
                  multiple = TRUE
                )
                
              )
            ),
            fluidRow(
              box(width = 4, title = 'Sliders',
                  sliderInput("action10", label = " ",min = 0, max = 100, value = 50, dragRange = FALSE),
                  br(),
                  p(code("sliderInput(, value = 50)")),
                  sliderInput("slider23", "",
                              min = 0, max = 100, value = c(25, 75)),
                  br(),
                  p(code("sliderInput(, value = c(25,75))"))
              ),
              box(width = 4, title = 'Text input', 
                  textInput("action11", label = " ", value = ' '),
                  br(),
                  p(code("textInput()")),
                  passwordInput("action12", label = " ", value= 'jdlsjs'),
                  br(),
                  p(code("passwordInput()"))
              ),
              box(width = 4, title = 'Color input', 
                  colourInput("col2", " ", "red"),
                  br(),
                  p(code("colourpicker::colourInput()"))
                  
                  
                  
              )
            ),
            fluidRow(
             # box(width = 4, title = 'Sliders',
              #    materialSwitch(inputId = "id", label = "Primary switch", status = "primary", right = TRUE)
                  
              #),
              box(width = 4, title = 'Text input', 
                  checkboxGroupButtons(
                    inputId = "somevalue", label = "Make a choice :", 
                    choices = c("Choice A", "Choice B", " Choice C", "Choice D"), 
                    justified = TRUE, status = "primary",
                    checkIcon = list(yes = icon("ok", lib = "glyphicon"), no = icon("remove", lib = "glyphicon"))
                  )
              ),
              box(width = 4, title = 'Color input', 
                  searchInput(
                    inputId = "id", 
                    label = "Enter your search :", 
                    placeholder = "This is a placeholder", 
                    btnSearch = icon("search"), 
                    btnReset = icon("remove"), 
                    width = "100%"
                  )
                  
                  
                  
              )
            )
            
            ),
    
     tabItem(tabName = "output",
             h2('Les differents outputs disponibles:'),
             
             box(width = 12, title = 'Table output', status = 'danger', solidHeader = TRUE,
                 collapsible = TRUE, collapsed = TRUE,
                 div(style = 'overflow-x: scroll;',DT::dataTableOutput('dataTable2'))),
             box(width = 12, title = 'Text output', status = 'danger', solidHeader = TRUE,
                 collapsible = TRUE, collapsed = TRUE,
                 
                 div(style = 'overflow-x: scroll;',verbatimTextOutput("print") ))
             
             
             
             
             ,
             
             box(width = 12, title = 'Plot output', status = 'danger', solidHeader = TRUE,
                 collapsible = TRUE, collapsed = TRUE,
                 
                 plotOutput('plot')),
             box(width = 12, title = 'interactive plots', status = 'danger', solidHeader = TRUE,
                 collapsible = TRUE, collapsed = TRUE,
                 
                 plotlyOutput("plotPlotly"))
             
           
     ),
    tabItem(tabName = 'Autres',
            h2("D'autres possibilites avec Shiny")),
    
    
    tabItem(tabName = 'video',
            fluidRow(
              box( width = 8, title = 'video YouTube',
                   div(align = "center", embed_youtube(id = "cU0-NrUxRw4"))            )
              
              
              
            )),
    tabItem(tabName = 'rapport',
            fluidRow(
              column(width = 4,
                     box(width = NULL, title = "Regression",
                         selectInput('ycolReg', 'Y Variable', names(iris),
                                     selected=names(iris)[[2]]),
                         selectInput('xcolReg', 'X Variable', names(iris),  selected =names(iris)[!names(iris) %in% names(iris)[[2]]], multiple = TRUE)
                         
                         
                     ),
                     box(width = NULL,title = "Rapport",
                         textInput('title', 'Entrer le titre du rapport', value = 'Entrer le titre....'),
                         br(),
                         htmlOutput("rep"))
              ),
              box(title = "Resultat de la regression",
                  verbatimTextOutput("reg")
                  
              ))
            
    ),
    
    tabItem(tabName = 'ggmap',
            fluidRow(
              box(width = 4, 
                  textInput('adresse','Localisation:', value = " ")),
              htmlOutput('gvisCrunsh')
            )
    ),
    tabItem(
      
      tabName = "krsl",
      
      h2("Carousel Slide Show"),
      
      ygdashboard::carouselBox(
        
        title = "Carousel Exemples", footer = " ", status = "success", 
        solidHeader = TRUE, background = NULL, width = 12L, # height = 400L,
        collapsible = TRUE, collapsed = FALSE,
        
        ygdashboard::carouselSets(
          
          id = "carouselExample",
          
          ygdashboard::carouselItem(
            
            tags$p(style="text-align:center", tags$img(src="Capture1.PNG", style="width:auto; height:400px;")), 
            
            caption = "Stability product"
            
          ),
          
          ygdashboard::carouselItem(
            
            tags$p(style="text-align:center", tags$img(src="Capture2.PNG", style="width:auto; height:400px;")), 
            
            caption = "Suivi de produit"
            
          ),
          
          ygdashboard::carouselItem(
            
            tags$p(style="text-align:center", tags$img(src="Capture3.PNG", style="width:auto; height:400px;")), 
            
            caption = "Rapport automatique"
            
          )
          
        )
        
      )#,
      
      #textOutput(outputId = "carouselActiveItem")
      
    ),
    
    tabItem(tabName = "Ngram",
            box(width= 4,collapsible= TRUE,status = "warning", solidHeader = TRUE, br(), 
                textInput("searchButton2", label = "Word:",
                                  value = "Figure"),
              sliderInput("daterange", h3("Year range"),
                          min = 1800, max = 2008, value = c(1900,2000)),
              # dateRangeInput("daterange", h3("Year range:"),format = "yyyy", start="1900-01-01", end="2000-01-01", startview = "decade"),
              selectInput("checkbox", 
                          label = h3("Choose the corpus"), 
                          choices = list("American English 2012" = "eng_us_2012", 
                                         "American English 2009" = "eng_us_2009",
                                         "British English 2012" = "eng_gb_2012",
                                         "British English 2009" = "eng_gb_2009",
                                         "English 2012" = "eng_2012",
                                         "English 2009" = "eng_2009",
                                         "English Fiction 2012" = "eng_fiction_2012",
                                         "English Fiction 2009" = "eng_fiction_2009",
                                         "Google One Million" = "eng_1m_2009",
                                         "French 2012" = "fre_2012",
                                         "French 2009" = "fre_2009"
                          ),
                          selected = "eng_us_2009"),
              selectInput("plotChoice", 
                          label = NULL,
                          choices = list("Google Viewer and corrected trend" = "all", 
                                         "Google Viewer" = "google", "Corrected trend" = "corrected"),
                          selected = "all"
              )
            ),
              
              box(title= "Extracting useful information from the Google Ngram
                  dataset: A general method to take the growth of the scientific literature into account" ,statut = "primary",collapsible= TRUE,solidHeader = TRUE, br(),
                  plotlyOutput("plot.corrected"), width =8)
              
              
              
            ),
    tabItem(tabName = "taille",
            h2("Taille de l'echantillon dans un plan de sondage aleatoire simple"),
            fluidRow(box(
              title = "Parametres a specifier par l'usager", solidHeader = TRUE,
              br(), 
              numericInput("niveau.confiance", paste0("Niveau de confiance (1-alpha) en pourcentage:"), min=70, max=100, value=95),
              numericInput("prop.erreur", "Proportion d'erreur prevu (p):", min=1, max=100, value=50),
              numericInput("marge.erreur", "Marge d'erreur (d) en pourcentage:", min=0, max=50, value=5),
              numericInput("taille.pop", "Taille de la population (N):", value=100, min=1, max=10^9)
            )
            ,
            
            box(title = 'Resultat:', solidHeader = TRUE,br(),status = 'danger',
                "Arrondir la taille a l'entier le plus eleve", br(),h4(textOutput('calcul.taille')))
            )),
    
    tabItem(tabName = "marge",
            h2("Marge d'erreur dans un plan de sondage aleatoire simple"),
            fluidRow(box(
              title = "Parametres a specifier par l'usager", solidHeader = TRUE,
              br(), 
              numericInput("niveau.confiance2", "Niveau de confiance (1-alpha) en pourcentage:", min=70, max=100, value=95),
              numericInput("prop.erreur2", "Proportion d'erreur prevu (p):", min= 1, max=100, value=50), 
              numericInput("taille.pop2", "Taille de la population (N):", value=1000, min=1, max=10^9),
              numericInput("taille.echan2", "Taille de l'echantillon (n):", value=100, min=1, max=10^9)
            ),
            
            
            box(h4(textOutput('calcul.marge')), title = 'Resultat:', solidHeader = TRUE,br(), status = 'danger'))
    ),
    
    
    
    
    # Stratifie
    ###########
    tabItem(tabName = "taillestrat",
            h2("Taille de l'echantillon dans un plan stratifie avec allocation de Neymann"),
            fluidRow(box(
              title = "Parametres a specifier par l'usager", solidHeader = TRUE,
              br(), 
              numericInput("niveau.confianceS", paste0("Niveau de confiance (1-alpha) en pourcentage:"), min=70, max=100, value=95),
              numericInput("marge.erreurS", "Marge d'erreur (d) en pourcentage:", min=0, max=50, value=5),
              numericInput("taille.popS", "Taille de la population (N):", value=700, min=1, max=10^9),
              numericInput("k", "Nombres de strates (k):", min=2, max=5, value=3)
              
              
            ),
            
            conditionalPanel(
              condition = "input.k == 2",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1k2", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value= 50),
                         numericInput("n1k2"," taille prevu (N1):", min=0, max=10^9, value=300)),
                tabPanel("Strate 2",
                         numericInput("p2k2", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2k2"," taille prevu (N2):", min=0, max=10^9, value=300)
                )
                
                
              )),
            conditionalPanel(
              condition = "input.k == 3",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1k3", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value=50),
                         numericInput("n1k3"," taille prevu (N1):", min=0, max=10^9, value=150)),
                tabPanel("Strate 2",
                         numericInput("p2k3", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2k3"," taille prevu (N2):", min=0, max=10^9, value=150)),
                tabPanel("Strate 3",
                         numericInput("p3k3", paste0("Proportion d'erreur prevu (P3):"), min=0, max=100, value=50),
                         numericInput("n3k3"," taille prevu (N3):", min=0, max=10^9, value=150)
                )
                
                
              )),
            conditionalPanel(
              condition = "input.k == 4",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1k4", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value=50),
                         numericInput("n1k4"," taille prevu (N1):", min=0, max=10^9, value=150)),
                tabPanel("Strate 2",
                         numericInput("p2k4", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2k4"," taille prevu (N2):", min=0, max=10^9, value=150)),
                tabPanel("Strate 3",
                         numericInput("p3k4", paste0("Proportion d'erreur prevu (P3):"), min=0, max=100, value=50),
                         numericInput("n3k4"," taille prevu (N3):", min=0, max=10^9, value=150)
                ),
                tabPanel("Strate 4",
                         numericInput("p4k4", paste0("Proportion d'erreur prevu (P4):"), min=0, max=100, value=50),
                         numericInput("n4k4"," taille prevu (N4):", min=0, max=10^9, value=150)
                )
                
                
              )),
            conditionalPanel(
              condition = "input.k == 5",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1k5", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value=50),
                         numericInput("n1k5"," taille prevu (N1):", min=0, max=10^9, value=150)),
                tabPanel("Strate 2",
                         numericInput("p2k5", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2k5"," taille prevu (N2):", min=0, max=10^9, value=150)),
                tabPanel("Strate 3",
                         numericInput("p3k5", paste0("Proportion d'erreur prevu (P3):"), min=0, max=100, value=50),
                         numericInput("n3k5"," taille prevu (N3):", min=0, max=10^9, value=150)
                ),
                tabPanel("Strate 4",
                         numericInput("p4k5", paste0("Proportion d'erreur prevu (P4):"), min=0, max=100, value=50),
                         numericInput("n4k5"," taille prevu (N4):", min=0, max=10^9, value=150)
                ),
                tabPanel("Strate 5",
                         numericInput("p5k5", paste0("Proportion d'erreur prevu (P5):"), min=0, max=100, value=50),
                         numericInput("n5k5"," taille prevu (N5):", min=0, max=10^9, value=150)
                )
                
                
              ))
            ),
            box(title = 'Resultat:', solidHeader = TRUE,br(), status = 'danger', 
                "Arrondir la taille a l'entier le plus eleve",br(),h4(textOutput('calcul.tailleStrate'))),
            box(h4(tableOutput('nh')), title = 'Taille dans chaque strate:', solidHeader = TRUE,br(), status = 'danger')
            
            
            
            
    ),
    tabItem(tabName = "margestart",
            h2("Marge d'erreur dans un plan stratifie avec allocation de Neymann"),
            fluidRow(box(
              title = "Parametres a specifier par l'usager", solidHeader = TRUE,
              br(), 
              numericInput("niveau.confianceS2", paste0("Niveau de confiance (1-alpha) en pourcentage:"), min=70, max=100, value=95),
              numericInput("taille.popS2", "Taille de la population (N):", value=700, min=1, max=10^9),
              numericInput("taille.echS2", "Taille de l'echantillon (n):", value=200, min=1, max=10^9),
              numericInput("k2", "Nombres de strates (k):", min=2, max=5, value=3)
              
              
            ),
            
            conditionalPanel(
              condition = "input.k2 == 2",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1mk2", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value= 50),
                         numericInput("n1mk2"," taille prevu (N1):", min=0, max=10^9, value=150)),
                tabPanel("Strate 2",
                         numericInput("p2mk2", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2mk2"," taille prevu (N2):", min=0, max=10^9, value=150)
                )
                
                
              )),
            conditionalPanel(
              condition = "input.k2 == 3",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1mk3", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value=50),
                         numericInput("n1mk3"," taille prevu (N1):", min=0, max=10^9, value=150)),
                tabPanel("Strate 2",
                         numericInput("p2mk3", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2mk3"," taille prevu (N2):", min=0, max=10^9, value=150)),
                tabPanel("Strate 3",
                         numericInput("p3mk3", paste0("Proportion d'erreur prevu (P3):"), min=0, max=100, value=50),
                         numericInput("n3mk3"," taille prevu (N3):", min=0, max=10^9, value=150)
                )
                
                
              )),
            conditionalPanel(
              condition = "input.k2 == 4",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1mk4", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value=50),
                         numericInput("n1mk4"," taille prevu (N1):", min=0, max=10^9, value=150)),
                tabPanel("Strate 2",
                         numericInput("p2mk4", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2mk4"," taille prevu (N2):", min=0, max=10^9, value=150)),
                tabPanel("Strate 3",
                         numericInput("p3mk4", paste0("Proportion d'erreur prevu (P3):"), min=0, max=100, value=50),
                         numericInput("n3mk4"," taille prevu (N3):", min=0, max=10^9, value=150)
                ),
                tabPanel("Strate 4",
                         numericInput("p4mk4", paste0("Proportion d'erreur prevu (P4):"), min=0, max=100, value=50),
                         numericInput("n4mk4"," taille prevu (N4):", min=0, max=10^9, value=150)
                )
                
                
              )),
            conditionalPanel(
              condition = "input.k2 == 5",
              tabBox( 
                title = "",
                tabPanel("Strate 1",
                         numericInput("p1mk5", paste0("Proportion d'erreur prevu (P1):"), min=0, max=100, value=50),
                         numericInput("n1mk5"," taille prevu (N1):", min=0, max=10^9, value=150)),
                tabPanel("Strate 2",
                         numericInput("p2mk5", paste0("Proportion d'erreur prevu (P2):"), min=0, max=100, value=50),
                         numericInput("n2mk5"," taille prevu (N2):", min=0, max=10^9, value=150)),
                tabPanel("Strate 3",
                         numericInput("p3mk5", paste0("Proportion d'erreur prevu (P3):"), min=0, max=100, value=50),
                         numericInput("n3mk5"," taille prevu (N3):", min=0, max=10^9, value=150)
                ),
                tabPanel("Strate 4",
                         numericInput("p4mk5", paste0("Proportion d'erreur prevu (P4):"), min=0, max=100, value=50),
                         numericInput("n4mk5"," taille prevu (N4):", min=0, max=10^9, value=150)
                ),
                tabPanel("Strate 5",
                         numericInput("p5mk5", paste0("Proportion d'erreur prevu (P5):"), min=0, max=100, value=50),
                         numericInput("n5mk5"," taille prevu (N5):", min=0, max=10^9, value=150)
                )
                
                
              ))
            ),
            box(h4(textOutput('calcul.margeStrate')), title = 'Resultat:', solidHeader = TRUE, br(), status = 'danger'),
            box(h4(tableOutput('nhMarge')), title = 'Taille dans chaque strate:', solidHeader = TRUE,br(), status = 'danger')
            
            
            
            
    ),
    
    tabItem(tabName = "mixed",
            fluidRow(
              column(width = 4,
            box(width = NULL, title = "Data import", status = 'primary',solidHeader = TRUE,collapsible = TRUE,
                radioButtons(inputId = 'inputformat',
                             label = 'What type of file are you uploading?',
                             choices = c('Excel' = 'excel', 'CSV' = 'csv')),         
                # numericInput(inputId = 'datacol',
                #              label = 'Which column are the short URLs in?',
                #              value = 1,
                #              min = 1,
                #              max = 10,
                #              step = 1), br(), br(),      
                # helpText('Does the short URL column have a header row?'),
                # checkboxInput(inputId = 'dataheader',label = 'Yes',value = TRUE),
                fileInput(inputId = 'datafile', label = ''),
                uiOutput('worksheets')),
                uiOutput("formula") ,
            uiOutput('boxData')
              )

           
            ,
           
            uiOutput("resultReg")
            
            )
  ),
  
  tabItem(tabName = "text",
        fluidRow(
            box(width = 6, title = "Data import", status = 'primary',solidHeader = TRUE,collapsible = TRUE,
              
                column(width = 5,
                       textInput("link", label = p("Provide link(s) to your PDF document(s) separated by comma",style="text-align:center;color:#990099;font-size:110%"),
                                 value = ""),

                       br()
                ),

                column(width = 3,

                       tags$h3("And/Or", style="text-align:center;color:blue;font-size:120%"),
                       br()

                ),
                column(width = 4,
                       fileInput('file1', em('Choose PDF File',style="text-align:center;color:red;font-size:120%"),multiple = TRUE,
                                 accept=c('.pdf')),
                       
                       br()
                )),
          
            
            
           
            box(title = "parameters", width = 6, status = 'primary',solidHeader = TRUE,collapsible = TRUE,
            
                   br(),
                   uiOutput("minfreq"),
                   br(),
                   uiOutput("maxwords"),
                   br(),
                   uiOutput("forEach")
            
        )),
        
          box(width = 12, title = "Word cloud",
                     plotOutput("wordcloud"))
        
          
        )
          ))
    
    
  )
